
import Setting from '@/setting'
import util from '@/libs/util'
import { Message } from 'element-ui'
import {post,get,del,put} from '@/plugins/requests/index.js'
import api from '@/api'

/**
 * 用户信息
 * */
export default {
    namespaced: true,
    state: {
        avatar: 'https://cube.elemecdn.com/3/7c/3ea6beec64369c2642b92c6726f1epng.png',
        userName: '',
        schoolId: '',
        isManager: false
    },
    mutations: {
        SET_INFO: (state, info) => {
            if(info.avatar) state.avatar = info.avatar
            state.schoolId = info.schoolId
            state.userName = info.userName
        },
        SET_AVATAR: (state, avatar) => {
            state.avatar = avatar
        },
        SET_MANAGER: (state, isManager) => {
            state.isManager = isManager
        },
    },
    actions: {
        login({ state,commit }, userInfo) {
            const { account, password, code, random } = userInfo
            return new Promise((resolve, reject) => {
                post(api.logins,{
                    account,
                    password,
                    code,
                    platform: Setting.platformId,
                    random,
                }).then(res => {
                    setTimeout(() => {
                        post(api.saveRecord,{
                            type: 3,
                        }).then(res => {}).catch(res => {})
                    },3000)
                    
                    if(res.status == 200){
                        util.local.set(Setting.tokenKey,res.data.token,1296000000)
                        util.successMsg('登录成功')
                        resolve()
                    }else{
                        util.errorMsg(res.message)
                        reject(res)
                    }
                }).catch(error => {
                    reject(error)
                })
            })
        },
        logout({ commit, state, dispatch }) {
            return new Promise((resolve, reject) => {
                util.local.remove(Setting.storeKey)
                util.local.remove(Setting.tokenKey)
                location.reload()
                resolve()
            })
        },
        setAvatar({ state,commit },avatar) {
            commit('SET_AVATAR',avatar)
            let data = {
                userId: state.userId,
                userAvatars: avatar
            }
            post(api.userinfoUpdate,data).then(res => {}).catch(res => {})
        },
        setInfo({ state,commit },info) {
            commit('SET_INFO',info)
        },
        setManager({ state,commit },isManager) {
            commit('SET_MANAGER',isManager)
        },
    }
}